@@ -605,19 +605,18 @@ streamFile(stream_t stream, const char *fileName)
 					continue;
 				if (cfg_get_metadata_program()) {
 					char		*mdataStr = NULL;
-					mdata_t 	 prog_md;
 
 					log_info("running metadata program: %s",
 					    cfg_get_metadata_program());
-					prog_md = mdata_create();
+					md = mdata_create();
 					if (0 > mdata_run_program(md, cfg_get_metadata_program()) ||
-					    0 > stream_set_metadata(stream, prog_md, &mdataStr)) {
-						mdata_destroy(&prog_md);
+					    0 > stream_set_metadata(stream, md, &mdataStr)) {
+						mdata_destroy(&md);
 						retval = 0;
 						ret = STREAM_DONE;
 						continue;
 					}
-					mdata_destroy(&prog_md);
+					mdata_destroy(&md);
 					log_info("new metadata: %s", mdataStr);
 					xfree(mdataStr);
 				}
@@ -749,8 +748,10 @@ main(int argc, char *argv[])
 	}
 
 	main_stream = stream_create(CFG_DEFAULT);
-	if (0 > stream_configure(main_stream))
+	if (0 > stream_configure(main_stream)) {
+		stream_destroy(&main_stream);
 		return (ez_shutdown(1));
+	}
 	cfg_server = stream_get_cfg_server(main_stream);
 	cfg_stream = stream_get_cfg_stream(main_stream);
 	cfg_intake = stream_get_cfg_intake(main_stream);
@@ -763,6 +764,7 @@ main(int argc, char *argv[])
 	for (i = 0; i < sizeof(ezstream_signals) / sizeof(int); i++) {
 		if (sigaction(ezstream_signals[i], &act, NULL) == -1) {
 			log_syserr(ERROR, errno, "sigaction");
+			stream_destroy(&main_stream);
 			return (ez_shutdown(1));
 		}
 	}
@@ -776,6 +778,7 @@ main(int argc, char *argv[])
 	act.sa_handler = SIG_IGN;
 	if (sigaction(SIGPIPE, &act, NULL) == -1) {
 		log_syserr(ERROR, errno, "sigaction");
+		stream_destroy(&main_stream);
 		return (ez_shutdown(1));
 	}
 
@@ -784,6 +787,7 @@ main(int argc, char *argv[])
 
 	if (0 > stream_connect(main_stream)) {
 		log_error("initial server connection failed");
+		stream_destroy(&main_stream);
 		return (ez_shutdown(1));
 	}
 	log_notice("connected: %s://%s:%u%s",
@@ -815,6 +819,7 @@ main(int argc, char *argv[])
 	} while (cont);
 
 	stream_disconnect(main_stream);
+	stream_destroy(&main_stream);
 
 	if (quit) {
 		if (cfg_get_program_quiet_stderr() &&
